/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.fol;

import edu.freiburg.dbis.rdd.sparql.IRI;
import edu.freiburg.dbis.rdd.sparql.SPARQLVariable;

/**
 * Class representing either a FO IRI or a SPARQL variable
 * 
 * @author MSchmidt
 */
public class FOIRIOrSPARQLVariable {
	
	protected SPARQLVariable var;
	protected IRI iri;
	
	public FOIRIOrSPARQLVariable(SPARQLVariable var) {
		this.var = var;
		iri = null;
	}
	
	public FOIRIOrSPARQLVariable(IRI iri) {
		this.iri = iri;
		var = null;
	}
	
	@Override
	public String toString() {
		if (var!=null)
			return var.toString();
		if (iri!=null)
			return iri.toString();
		
		return null; // fallback (should never happen)
	}
	
	public String toSPARQL() {
		if (var!=null)
			return var.toSPARQL();
		if (iri!=null)
			return iri.toSPARQL();

		return null; // fallback (should never happen)
	}
}