/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.model;

import java.util.LinkedList;
import java.util.List;

/**
 * Representation of a set of {@link PrefixDecl} inside an RDD
 * 
 * @author MSchmidt
 */
public class PrefixSec {
	protected List<PrefixDecl> prefixes;
	
	public PrefixSec() {
		prefixes = new LinkedList<PrefixDecl>();
	}
	
	public void addPrefixDecl(PrefixDecl prefix) {
		prefixes.add(prefix);
	}
	
	public List<PrefixDecl> getPrefixes() {
		return prefixes;
	}
	
	/**
	 * Resolves the prefix. If not resolvable, null is returned.
	 */
	public String resolvePrefix(String prefix) {
		for (PrefixDecl prefixDecl : prefixes) {
			if (prefix.equals(prefixDecl.getPrefix()))
				return prefixDecl.getIri();
		}
		
		return null; // no success in resolving
	}

	
	@Override
	public String toString() {
		StringBuffer buf = new StringBuffer();
		for (PrefixDecl prefix : prefixes) {
			buf.append(prefix.toString());
			buf.append("\n");
		}
		if (!prefixes.isEmpty())
			buf.append("\n");
		
		return buf.toString();
	}
}
