/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.model;

import java.util.HashSet;
import java.util.Set;

import edu.freiburg.dbis.rdd.fol.FOConvertable;
import edu.freiburg.dbis.rdd.fol.FOFormula;
import edu.freiburg.dbis.rdd.semantics.Environment;

/**
 * POJO representation of a parsed RDD
 * 
 * @author MSchmidt
 */
public class RDD implements FOConvertable {
	
	protected PrefixSec ps;
	protected ClassConstraintSec ccs;
	protected PropConstraintSec pcs;
	
	public RDD(PrefixSec ps, ClassConstraintSec ccs, PropConstraintSec pcs) {
		this.ps = ps;
		this.ccs = ccs;
		this.pcs = pcs;
	}
	
	public PrefixSec getPrefixSec() {
		return ps;
	}
	
	public ClassConstraintSec getClassConstraintSec() {
		return ccs;
	}
	
	public PropConstraintSec getPropConstraintSec() {
		return pcs;
	}
	
	@Override 
	public String toString() {
		StringBuffer buf = new StringBuffer();
		
		if (ps!=null)
			buf.append(ps.toString());
		
		if (ccs!=null)
			buf.append(ccs.toString());
		
		if (ccs!=null && pcs!=null)
			buf.append("\n\n");
		
		if (pcs!=null)
			buf.append(pcs.toString());
		
		return buf.toString();
	}

	public Set<FOFormula> toFOL() {
		return toFOL(new Environment(this));
	}
	
	@Override
	public Set<FOFormula> toFOL(Environment e) {
		Set<FOFormula> ret = new HashSet<FOFormula>();
		if (ccs!=null)
			ret.addAll(ccs.toFOL(e));
		if (pcs!=null)
			ret.addAll(pcs.toFOL(e));
		return ret;
	}
}
