/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.model;

import java.util.List;

import edu.freiburg.dbis.rdd.fol.FOConstraintBuilder;
import edu.freiburg.dbis.rdd.fol.FOFormula;
import edu.freiburg.dbis.rdd.provenance.ConstraintProvenanceStringBuilder;
import edu.freiburg.dbis.rdd.semantics.Environment;
import edu.freiburg.dbis.rdd.sparql.IRI;

/**
 * Representation of a SUBPROPERTY constraint
 * 
 * @author MSchmidt
 */
public class SubPropertyConstraint extends PropConstraint {
	protected List<IRI> subProps;
	
	public SubPropertyConstraint(List<IRI> subProps) {
		super();
		this.subProps = subProps;
	}

	public List<IRI> getSubProps() {
		return subProps;
	}
	
	@Override
	public String toString() {
		StringBuffer buf = new StringBuffer();
		buf.append("SUBPROPERTY(");
		
		int i=0;
		for (IRI subProp : subProps)
		{
			if (i++>0)
				buf.append(",");
			buf.append(subProp);
		}
		buf.append(") ");
		buf.append(propWithRangeType);
		buf.append(";");
		
		return buf.toString();
	}

	@Override
	public List<FOFormula> toFOL(IRI clazz, Environment e) {
		List<FOFormula> ret = super.toFOL(clazz,e);
		ret.addAll(FOConstraintBuilder.subPropertyConstraint(
			clazz,propWithRangeType.getIRI(), subProps, e,
			ConstraintProvenanceStringBuilder.propertyConstraint(clazz, this)));
		
		return ret;		
	}
}