/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.parser;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;

import org.junit.Test;

import edu.freiburg.dbis.rdd.model.ClassConstraint;
import edu.freiburg.dbis.rdd.model.ClassConstraintSec;
import edu.freiburg.dbis.rdd.model.PropConstraintSec;
import edu.freiburg.dbis.rdd.model.RDD;

/**
 * Test different capitalization of properties (we support
 * both capital letters and mixed versions)
 * 
 * @author MSchmidt
 */
public class CapitalizationTest {

	private static String TEST_BASE_DIR = "examples/test/parse/";
	
	@Test
	public void testOWACWASingletonParsing()
	throws FileNotFoundException, ParseException {
		
		// STEP 1: first parsing round, and check that prefixes
		// are parsed correctly and prefix manager is properly
		// set up after parsing
		String rddFile = TEST_BASE_DIR + "OWACWASingleton.rdd";
		FileInputStream fis = new FileInputStream(new File(rddFile));

	    RDDParser parser = new RDDParser(fis);
	    RDD rdd = parser.rdd();	
	    
	    ClassConstraintSec ccs = rdd.getClassConstraintSec();
	    PropConstraintSec pcs = rdd.getPropConstraintSec();
	    
	    for (ClassConstraint cc : ccs.getClassConstraints()) {
	    	if (cc.getClazz().toString().equals("<http://www.example.com/c1>"))
	    		assertTrue(cc.isOWA() && !cc.isSingleton());
	    	else if (cc.getClazz().toString().equals("<http://www.example.com/c2>"))
	    		assertTrue(!cc.isOWA() && !cc.isSingleton());
	    	else if (cc.getClazz().toString().equals("<http://www.example.com/c3>"))
	    		assertTrue(cc.isOWA() && cc.isSingleton());
	    	else if (cc.getClazz().toString().equals("<http://www.example.com/c4>"))
	    		assertTrue(!cc.isOWA() && cc.isSingleton());
	    	else
	    		assertTrue(false); // this case should never happen
	    }
	    assertTrue(pcs.isOWA());
	}
}
