/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.parser;

import static org.junit.Assert.assertEquals;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.List;

import org.junit.Test;

import edu.freiburg.dbis.rdd.model.ClassConstraint;
import edu.freiburg.dbis.rdd.model.ClassConstraintSec;
import edu.freiburg.dbis.rdd.model.DomainConstraint;
import edu.freiburg.dbis.rdd.model.MaxConstraint;
import edu.freiburg.dbis.rdd.model.MinConstraint;
import edu.freiburg.dbis.rdd.model.PartialityConstraint;
import edu.freiburg.dbis.rdd.model.PathConstraint;
import edu.freiburg.dbis.rdd.model.PropConstraint;
import edu.freiburg.dbis.rdd.model.PropConstraintSec;
import edu.freiburg.dbis.rdd.model.RDD;
import edu.freiburg.dbis.rdd.model.RangeConstraint;
import edu.freiburg.dbis.rdd.model.SubPropertyConstraint;
import edu.freiburg.dbis.rdd.model.TotalityConstraint;

/**
 * Parsing test for the individual types encapsulated into
 * PROPERTIES and CLASSES section, each.
 * 
 * @author MSchmidt
 */
public class MultiplePropertiesTest {

	private static String TEST_BASE_DIR = "examples/test/parse/";
	
	List<Class<?>> constraintTypes;
	
	@Test
	public void testMultiplePropertiesInPropSec()
	throws FileNotFoundException, ParseException {
		String rddFile = TEST_BASE_DIR + "MultiplePropertiesInPropertySec.rdd";
		FileInputStream fis = new FileInputStream(new File(rddFile));

	    RDDParser parser = new RDDParser(fis);
	    RDD rdd = parser.rdd();	

	    System.out.println(rdd);
	    System.out.println("\n\n");
	    
	    PropConstraintSec pcs = rdd.getPropConstraintSec();
	    List<PropConstraint> pcList = pcs.getPropConstraints();
	    
		int nrPropConstraint = 0;
		int nrTotalityConstraint = 0;
		int nrPartialityConstraint = 0;
		int nrMinConstraint = 0;
		int nrMaxConstraint = 0;
		int nrDomainConstraint = 0;
		int nrRangeConstraint = 0;
		int nrPathConstraint = 0;
		int nrSubPropertyConstraint = 0;

	    for (PropConstraint pc : pcList) {
	    	if (pc.getClass().equals(PropConstraint.class))
	    		nrPropConstraint++;
	    	if (pc.getClass().equals(TotalityConstraint.class))
	    		nrTotalityConstraint++;
	    	if (pc.getClass().equals(PartialityConstraint.class))
	    		nrPartialityConstraint++;
	    	if (pc.getClass().equals(MinConstraint.class))
	    		nrMinConstraint++;
	    	if (pc.getClass().equals(MaxConstraint.class))
	    		nrMaxConstraint++;
	    	if (pc.getClass().equals(DomainConstraint.class))
	    		nrDomainConstraint++;
	    	if (pc.getClass().equals(RangeConstraint.class))
	    		nrRangeConstraint++;
	    	if (pc.getClass().equals(PathConstraint.class))
	    		nrPathConstraint++;
	    	if (pc.getClass().equals(SubPropertyConstraint.class))
	    		nrSubPropertyConstraint++;
	    }
	    assertEquals(1,nrPropConstraint);
	    assertEquals(1,nrTotalityConstraint);
	    assertEquals(1,nrPartialityConstraint);
	    assertEquals(1,nrMinConstraint);
	    assertEquals(1,nrMaxConstraint);
	    assertEquals(1,nrDomainConstraint);
	    assertEquals(1,nrRangeConstraint);
	    assertEquals(1,nrPathConstraint);
	    assertEquals(1,nrSubPropertyConstraint);

	    ClassConstraintSec ccs = rdd.getClassConstraintSec();
	    List<ClassConstraint> ccList = ccs.getClassConstraints();
	    for (ClassConstraint cc : ccList) {
		    List<PropConstraint> pcList2 = cc.getPropConstraints();
		    for (PropConstraint pc : pcList2) {
		    	if (pc.getClass().equals(PropConstraint.class))
		    		nrPropConstraint++;
		    	if (pc.getClass().equals(TotalityConstraint.class))
		    		nrTotalityConstraint++;
		    	if (pc.getClass().equals(PartialityConstraint.class))
		    		nrPartialityConstraint++;
		    	if (pc.getClass().equals(MinConstraint.class))
		    		nrMinConstraint++;
		    	if (pc.getClass().equals(MaxConstraint.class))
		    		nrMaxConstraint++;
		    	if (pc.getClass().equals(DomainConstraint.class))
		    		nrDomainConstraint++;
		    	if (pc.getClass().equals(RangeConstraint.class))
		    		nrRangeConstraint++;
		    	if (pc.getClass().equals(PathConstraint.class))
		    		nrPathConstraint++;
		    	if (pc.getClass().equals(SubPropertyConstraint.class))
		    		nrSubPropertyConstraint++;
		    }	    	
	    }
	    assertEquals(2,nrPropConstraint);
	    assertEquals(2,nrTotalityConstraint);
	    assertEquals(2,nrPartialityConstraint);
	    assertEquals(2,nrMinConstraint);
	    assertEquals(2,nrMaxConstraint);
	    assertEquals(2,nrDomainConstraint);
	    assertEquals(2,nrRangeConstraint);
	    assertEquals(2,nrPathConstraint);
	    assertEquals(2,nrSubPropertyConstraint);
	}
}
