/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.parser;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import edu.freiburg.dbis.rdd.model.ClassConstraint;
import edu.freiburg.dbis.rdd.model.ClassConstraintSec;
import edu.freiburg.dbis.rdd.model.DomainConstraint;
import edu.freiburg.dbis.rdd.model.MaxConstraint;
import edu.freiburg.dbis.rdd.model.MinConstraint;
import edu.freiburg.dbis.rdd.model.PartialityConstraint;
import edu.freiburg.dbis.rdd.model.PathConstraint;
import edu.freiburg.dbis.rdd.model.PropConstraint;
import edu.freiburg.dbis.rdd.model.PropConstraintSec;
import edu.freiburg.dbis.rdd.model.RDD;
import edu.freiburg.dbis.rdd.model.RangeConstraint;
import edu.freiburg.dbis.rdd.model.SubPropertyConstraint;
import edu.freiburg.dbis.rdd.model.TotalityConstraint;

/**
 * Test parsing of the individual types encapsulated into
 * PROPERTIES and CLASSES section, each.
 * 
 * @author MSchmidt
 */
public class SingleTypeParseTest {

	private static String TEST_BASE_DIR = "examples/test/parse/";
	
	List<Class<?>> constraintTypes;

	@Test
	public void testSingleConstraintTypes() 
	throws FileNotFoundException, ParseException {
		initConstraintTypes();
		for (Class<?> clazz : constraintTypes) {
			runParseTest(clazz);
		}
	}
	
	void runParseTest(Class<?> clazz) 
	throws FileNotFoundException, ParseException {
		String rddFile = constraintTestFile(clazz);
		FileInputStream fis = new FileInputStream(new File(rddFile));

	    RDDParser parser = new RDDParser(fis);
	    RDD rdd = parser.rdd();	
	    
	    // print
	    System.out.println(rdd);
	    System.out.println("\n\n");
	    
	    // check the RDD structure: it must contain one instance
	    // of the respective constraint class both inside the class
	    // and inside the properties section
	    ClassConstraintSec ccs = rdd.getClassConstraintSec();
	    List<ClassConstraint> ccList = ccs.getClassConstraints();
	    boolean classSecTypeMatch=false;
	    for (ClassConstraint cc : ccList) {
		    List<PropConstraint> pcList = cc.getPropConstraints();
		    for (PropConstraint pc : pcList) {
		    	classSecTypeMatch |= pc.getClass().equals(clazz);
		    }	    	
	    }
	    assertTrue(classSecTypeMatch);
	    
	    PropConstraintSec pcs = rdd.getPropConstraintSec();
	    List<PropConstraint> pcList = pcs.getPropConstraints();
	    boolean propSecTypeMatch=false;
	    for (PropConstraint pc : pcList) {
	    	propSecTypeMatch |= pc.getClass().equals(clazz);
	    }
	    assertTrue(propSecTypeMatch);
	}

	String constraintTestFile(Class<?> clazz) {
		return new String(TEST_BASE_DIR + clazz.getSimpleName() + ".rdd");
	}
	
	void initConstraintTypes() {
		constraintTypes = new ArrayList<Class<?>>();
		constraintTypes.add(PropConstraint.class);
		constraintTypes.add(TotalityConstraint.class);
		constraintTypes.add(PartialityConstraint.class);
		constraintTypes.add(MinConstraint.class);
		constraintTypes.add(MaxConstraint.class);
		constraintTypes.add(DomainConstraint.class);
		constraintTypes.add(RangeConstraint.class);
		constraintTypes.add(PathConstraint.class);
		constraintTypes.add(SubPropertyConstraint.class);
	}
}
