/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.semantics;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Set;

import org.junit.Test;

import edu.freiburg.dbis.rdd.fol.FOFormula;
import edu.freiburg.dbis.rdd.model.RDD;
import edu.freiburg.dbis.rdd.parser.ParseException;
import edu.freiburg.dbis.rdd.parser.RDDParser;

/**
 * Test the implementation of the translation semantics for class keys.
 * 
 * @author MSchmidt
 */
public class ClassKeyTest {

	protected static String TEST_BASE_DIR = "examples/test/semantics/";

	@Test
	public void testClassKey() 
	throws FileNotFoundException, ParseException {
		
		String rddFile = TEST_BASE_DIR + "ClassKey.rdd";
		FileInputStream fis = new FileInputStream(new File(rddFile));

	    RDDParser parser = new RDDParser(fis);
	    RDD rdd = parser.rdd();	

	    Set<FOFormula> formulas = rdd.toFOL();

	    /**
	     * OWA CLASSES {
	     *   OWA CLASS <http://www.example.com/C1> {
	     *     KEY <http://www.example.com/p1>; 
	     *   }
	     *   
	     *   OWA CLASS <http://www.example.com/C2> {
	     *     KEY <http://www.example.com/p1>, <http://www.example.com/p2>, <http://www.example.com/p3>; 
	     *     KEY <http://www.example.com/p4>; 
	     *   }
	     * }
	     */
	    // constraints for C1
	    String minConstraintC1p1 = 
	    	Util.serializedMin1Constraint(Util.CLASS1, Util.PROP1);
	    String maxConstraintC1p1 = 
		    Util.serializedMax1Constraint(Util.CLASS1, Util.PROP1);
	    String keyConstraintC1 =
	    	Util.serializedKey1Constraint(Util.CLASS1, Util.PROP1);
	    
	    // constraints for C1
	    String minConstraintC2p1 = 
	    	Util.serializedMin1Constraint(Util.CLASS2, Util.PROP1);
	    String minConstraintC2p2 = 
		    Util.serializedMin1Constraint(Util.CLASS2, Util.PROP2);
	    String minConstraintC2p3 = 
			Util.serializedMin1Constraint(Util.CLASS2, Util.PROP3);
	    String minConstraintC2p4 = 
			Util.serializedMin1Constraint(Util.CLASS2, Util.PROP4);
	    
	    String maxConstraintC2p1 = 
			Util.serializedMax1Constraint(Util.CLASS2, Util.PROP1);
	    String maxConstraintC2p2 = 
			Util.serializedMax1Constraint(Util.CLASS2, Util.PROP2);
	    String maxConstraintC2p3 =  
			Util.serializedMax1Constraint(Util.CLASS2, Util.PROP3);
	    String maxConstraintC2p4 = 
			Util.serializedMax1Constraint(Util.CLASS2, Util.PROP4);

	    String keyConstraint1C2 =
			Util.serializedKey1Constraint(Util.CLASS2, Util.PROP4);

	    String keyConstraint2C2 =
			Util.serializedKey3Constraint(Util.CLASS2, Util.PROP1, Util.PROP2, Util.PROP3);
	    
	    Util.assertSemantics(formulas, 
	    	minConstraintC1p1, minConstraintC2p1, minConstraintC2p2, minConstraintC2p3, minConstraintC2p4,
	    	maxConstraintC1p1, maxConstraintC2p1, maxConstraintC2p2, maxConstraintC2p3, maxConstraintC2p4,
	    	keyConstraintC1, keyConstraint1C2, keyConstraint2C2);
	}
}